Warning: Do NOT sync the windows.*.idl files from wine. The
windows.storage.idl was added in wine recently. It does not have all
the symbols compared to the mingw-w64 one. VLC uses that
windows.storage.h file.

These d2d1 headers are required for cairo, not related to those
windows.*.idl files.
From cf1c3dba2b5dbcf36ffbf6a9d66ac4d9b5e98a6c Mon Sep 17 00:00:00 2001
From: Biswapriyo Nath <[email protected]>
Date: Sat, 22 Jul 2023 13:14:36 +0530
Subject: [PATCH 1/3] headers: Import all d2d1 headers from wine

Required for cairo

Signed-off-by: Biswapriyo Nath <[email protected]>
---
 mingw-w64-headers/Makefile.am    | 8 ++++++++
 mingw-w64-headers/wine-import.sh | 4 ++--
 2 files changed, 10 insertions(+), 2 deletions(-)

diff --git a/mingw-w64-headers/Makefile.am b/mingw-w64-headers/Makefile.am
index a80e29f..a6bd835 100644
--- a/mingw-w64-headers/Makefile.am
+++ b/mingw-w64-headers/Makefile.am
@@ -93,6 +93,14 @@ IDL_SRCS = \
   include/credentialprovider.idl \
   include/ctfutb.idl \
   include/ctxtcall.idl \
+  include/d2d1.idl \
+  include/d2d1_1.idl \
+  include/d2d1_2.idl \
+  include/d2d1_3.idl \
+  include/d2d1effectauthor.idl \
+  include/d2d1effects.idl \
+  include/d2d1effects_1.idl \
+  include/d2d1effects_2.idl \
   include/d3d10.idl \
   include/d3d10_1.idl \
   include/d3d10sdklayers.idl \
diff --git a/mingw-w64-headers/wine-import.sh b/mingw-w64-headers/wine-import.sh
index 7e2006c..b6d3621 100755
--- a/mingw-w64-headers/wine-import.sh
+++ b/mingw-w64-headers/wine-import.sh
@@ -234,8 +234,8 @@ for f in \
     import_idl $f.idl include
 done
 
-# Import all winrt IDLs
-for f in $WINE_DIR/include/windows.*.idl; do
+# Import all d2d1 and winrt IDLs
+for f in $WINE_DIR/include/d2d1*.idl $WINE_DIR/include/windows.*.idl; do
     import_idl $(basename $f) include
 done
 
-- 
2.41.0

_______________________________________________
Mingw-w64-public mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/mingw-w64-public

Reply via email to